@@ -42,7 +42,7 @@ class GetS3Handler(AWSConfig):
         command_output_str = stdout.decode("utf-8")
 
         try:
-            bucket_names_list = command_output_str.strip("\n").split("\t")
+            bucket_names_list = command_output_str.strip("\n").strip("\r").split("\t")
             return bucket_names_list
             
         except Exception as E:
@@ -76,17 +76,32 @@ class GetS3Handler(AWSConfig):
             
             exclude_pattern_str = f""" --query "Contents[? {exclude_filters_str} ].Key" """
         
+        obj_path_command = ""
+        if obj_path:
+            if obj_path[-1] != "/":
+                obj_path += "/"    
+            obj_path_command = f'--prefix "{obj_path}"'
         
-        command = f"""aws s3api list-objects --bucket "{bucket_name}" --prefix "{obj_path}" {include_pattern_str} {exclude_pattern_str} --profile {self.AWS_PROFILE_NAME} --output text"""
-
+        command = f"""aws s3api list-objects --bucket "{bucket_name}" {obj_path_command} --delimiter "/" {include_pattern_str} {exclude_pattern_str} --request-payer "requester" --profile {self.AWS_PROFILE_NAME} --output json"""
         process = Popen(command,shell=True,stdout=PIPE)
         stdout, _ = process.communicate()
         
         command_output_str =  stdout.decode("utf-8")
         try:
-            object_names_list = command_output_str.strip("\n").strip("\r").split("\t")
+            object_names_list = []
+            output_list = json.loads(command_output_str)
             
-            return object_names_list
+            if include_filters or exclude_filters:
+                return output_list
+            else:
+                if "Contents" in output_list:
+                    for content in output_list["Contents"]:
+                        object_names_list.append(content["Key"])
+                if "CommonPrefixes" in output_list:
+                    for prefix in output_list["CommonPrefixes"]:
+                        object_names_list.append(prefix["Prefix"])
+                
+                return object_names_list
             
         except Exception as E:
             print("No output found")
@@ -103,8 +118,10 @@ class GetS3Handler(AWSConfig):
         Args:
             bucket_name (string): Name of the bucket
             obj_path (string): Path of files in bucket (Default: '')
-            include_filters (list): list of strings to include in filtering
-            exclude_filters (list): list of strings to exclude in filtering
+            include_filters (list): list of sub strings to include in filtering 
+                                    Eg: ["20220101",".tif"] (No Wild card character allowed, only sub-strings)
+            exclude_filters (list): list of sub strings to exclude in filtering
+                                    Eg: ["20220101",".tif"] (No Wild card character allowed, only sub-strings)
         Returns:
             list: output/error list
         """
@@ -128,9 +145,9 @@ class GetS3Handler(AWSConfig):
         s3_obj_path = s3_obj_path.strip("/")
 
         if os.path.isdir(local_obj_path):
-            command = f"""aws s3 sync "{local_obj_path}" "s3://{bucket_name}/{s3_obj_path}" --profile {self.AWS_PROFILE_NAME} --output json"""
+            command = f"""aws s3 sync "{local_obj_path}" "s3://{bucket_name}/{s3_obj_path}" --request-payer "requester" --profile {self.AWS_PROFILE_NAME} --output json"""
         else:
-            command = f"""aws s3 cp "{local_obj_path}" "s3://{bucket_name}/{s3_obj_path}" --profile {self.AWS_PROFILE_NAME} --output json"""
+            command = f"""aws s3 cp "{local_obj_path}" "s3://{bucket_name}/{s3_obj_path}" --request-payer "requester" --profile {self.AWS_PROFILE_NAME} --output json"""
         
         process = Popen(command,shell=True,stdout=PIPE)
         stdout, _ = process.communicate()
@@ -141,7 +158,7 @@ class GetS3Handler(AWSConfig):
                          s3_obj_path: str ,
                          local_obj_path: str,
                          include_filters: list = [],
-                         exclude_filters:list = ["*"],
+                         exclude_filters:list = [],
                          dryrun: bool = False):
         
         include_filter_pattern = ""
@@ -157,8 +174,12 @@ class GetS3Handler(AWSConfig):
         if dryrun:
             dryrun_pattern = f"--dryrun"
         
-        command = f"""aws s3 sync {dryrun_pattern} "s3://{bucket_name}/{s3_obj_path}" "{local_obj_path}" {exclude_filter_pattern} {include_filter_pattern} --profile {self.AWS_PROFILE_NAME} --output json"""
-
+        if os.path.isdir(local_obj_path):
+            command = f"""aws s3 sync {dryrun_pattern} "s3://{bucket_name}/{s3_obj_path}" "{local_obj_path}" {exclude_filter_pattern} {include_filter_pattern} --request-payer "requester" --profile {self.AWS_PROFILE_NAME} """
+        else:
+            command = f"""aws s3 cp {dryrun_pattern} "s3://{bucket_name}/{s3_obj_path}" "{local_obj_path}" {exclude_filter_pattern} {include_filter_pattern} --request-payer "requester" --profile {self.AWS_PROFILE_NAME} """
+        
+        
         process = Popen(command,shell=True,stdout=PIPE)
         stdout, _ = process.communicate()
         return stdout.decode("utf-8")
@@ -168,7 +189,7 @@ class GetS3Handler(AWSConfig):
                          s3_obj_path: str ,
                          local_obj_path: str=".",
                          include_filters: list = [],
-                         exclude_filters:list = ["*"],
+                         exclude_filters:list = [],
                          dryrun: bool = False):
         """Download files/folders from s3 bucket
         
@@ -176,8 +197,10 @@ class GetS3Handler(AWSConfig):
             bucket_name (string): Name of bucket
             s3_obj_path (string): path on s3 bucket
             local_obj_path (string): Path on your machine
-            include_filters (list): list of strings to include in filtering
-            exclude_filters (list): list of strings to exclude in filtering
+            include_filters (list): list of sub strings to include in filtering 
+                                    Eg: ["20220101",".tif"] (No Wild card character allowed, only sub-strings)
+            exclude_filters (list): list of sub strings to exclude in filtering
+                                    Eg: ["20220101",".tif"] (No Wild card character allowed, only sub-strings)
             dryrun (bool): Displays the operations that would be performed using the specified command without actually running them
         Returns:
             string: output/error string
@@ -188,5 +211,4 @@ class GetS3Handler(AWSConfig):
                                local_obj_path,
                                include_filters,
                                exclude_filters,
-                               dryrun)
-       
+                               dryrun)
\ No newline at end of file
